bm_2023_bilateral_source: BM_2023 source-based bilateral decomposition of exports from s to r
Description
BM_2023 source-based bilateral decomposition of exports from s to r
Usage
bm_2023_bilateral_source(io, s, r)
Value
A data frame with the source-based value-added decomposition.
Arguments
- io
A bm_io object.
- s
Exporter country (name or index).
- r
Importer country (name or index).